# # SnipSnap::ActionMailerExtension
#
# Require Path: 'snipsnap/extensions/action_mailer'
#
# Optional:
#
# * `ENV['EMAIL_ADDRESS']` defaults to "smtp.sendgrid.net"
# * `ENV['URL_ROOT']` for prepending email URLs with `url_for(path)`
#
# Requires:
# * `gem 'actionmailer'`
# * `gem 'letter_opener'` in development
# * `ENV['EMAIL_DOMAIN']` for outgoing mail domain
# * `ENV['EMAIL_USER_NAME']` for sendgrid username
# * `ENV['EMAIL_PASSWORD']` for sendgrid password
#
require 'action_mailer'

module SnipSnap::ActionMailerExtension
  def self.registered(app)
    ActionMailer::Base.class_eval do
      helper do
        def url_for(path)
          url_root = ENV.fetch("URL_ROOT", "")
          [url_root, path].join
        end
      end
    end

    app.configure do
      ActionMailer::Base.tap do |config|
        config.delivery_method        = :smtp
        config.view_paths             = app.root
        config.raise_delivery_errors  = true
        config.smtp_settings          = {
          :authentication       => :plain,
          :enable_starttls_auto => true,
          :port                 => 25,
          :address              => ENV["EMAIL_ADDRESS"] || "smtp.sendgrid.net",
          :domain               => ENV["EMAIL_DOMAIN"],
          :user_name            => ENV["EMAIL_USER_NAME"],
          :password             => ENV["EMAIL_PASSWORD"]
        }
      end
    end

    app.configure :development do
      require 'letter_opener'

      ActionMailer::Base.tap do |config|
        config.add_delivery_method :letter_opener,
          LetterOpener::DeliveryMethod,
          location: app.root + "/tmp/letter_opener"
        config.delivery_method = :letter_opener
      end
    end

    app.configure :test do
      config.delivery_method = :test
    end
  end
end
