# # SnipSnap::Auth
#
# Require Path: `snipsnap/extensions/auth`
#
# Requires:
#
# * `Guest` model to act as an unfound user
#   * include the `SnipSnap::Guest` mixin into your Guest class
#
# * include the `SnipSnap::User` mixin into your
# * `User` model that
#   * responds to `authenticate` to check for password match (matching the `has_secure_password` interface)
#   * responds to `authorized?`
#

require 'snipsnap/models/user'
require 'snipsnap/models/guest'

module SnipSnap::AuthExtension
  def self.registered(app)
    app.helpers Helpers

    app.error 401..403 do
      headers = {
        'WWW-Authenticate' => %(Basic realm="Restricted Area")
      }
      body = {
        error: 'Unauthorized'
      }.to_json

      halt 401, headers, body
    end
  end

  module Helpers
    def restricted!
      halt 403 unless current_user.admin?
    end

    def protected!
      halt 401 unless authorized?
    end

    # XXX cache result after going through logic once?
    def authorized?
      current_user.authorized?
    end

    def current_user
      @current_user ||= begin
        auth ||=  Rack::Auth::Basic::Request.new(request.env)

        user = nil

        if auth.provided? && auth.basic? && auth.credentials
          email, password, _ = auth.credentials

          logger.info "Credentials for #{email}"

          # XXX URGENT NEED TO CHECK ACTUAL FACEBOOK TOKEN!
          @facebook_user = password.size > 16

          user = User.for(email)

          unless @facebook_user
            user = user.authenticate(password)
          end
        else
          logger.info "No credentials"
        end
        user || Guest.new
      end
    end

    def user_for_id(id)
      id == 'me' ?  current_user : User.find(id)
    end
  end
end
