# # SnipSnap::PaperclipExtension
#
# Require Path: `snipsnap/extensions/paperclip`
#
# Setup paperclip file management
#
# Requires:
# * `gem 'paperclip'`
# * `imagemagick` installed on system
#

require 'paperclip'

module SnipSnap::PaperclipExtension
  def self.registered(app)
    app.configure do
      Paperclip.io_adapters.register FileAdapter do |target|
        begin
          target.is_a?(Hash) && Tempfile === target[:tempfile]
        rescue => e
          false
        end
      end

      Paperclip.interpolates :rails_root  do |attachment, style|
        app.root
      end

      Paperclip.interpolates :guid  do |attachment, style|
        attachment.instance.guid
      end

      Paperclip.options[:command] = `which convert`
      Paperclip::Attachment.default_options.tap do |config|
        config[:url] = "/:attachment/:guid-:style.:extension"
      end
    end
  end

  class FileAdapter < Paperclip::AbstractAdapter
    def initialize(target)
      @target = target[:tempfile]
      cache_current_values(target)
    end

    private

    def cache_current_values(target)
      self.original_filename = target[:filename]
      self.original_filename ||= File.basename(@target.path)
      @tempfile = copy_to_tempfile(@target)
      @content_type = Paperclip::ContentTypeDetector.new(@target.path).detect
      @size = File.size(@target)
    end
  end
end
